@@ -19,7 +19,7 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include <QtTest/QTest>
+#include <QTest>
 
 #include "kblog/blogcomment.h"
 
